interface ClientSize {
    clientHeight?: number;
    clientWidth?: number;
}
interface DatasetLength {
    rowCount?: number;
    columnCount?: number;
}
interface ScrollSize {
    scrollHeight?: number;
    scrollWidth?: number;
}
interface ScrollPosition {
    scrollLeft?: number;
    scrollTop?: number;
}
declare enum ScrollAxisName {
    VERTICAL = "vertical",
    HORIZONTAL = "horizontal"
}
interface ScrollAxis<T> {
    [ScrollAxisName.VERTICAL]?: T;
    [ScrollAxisName.HORIZONTAL]?: T;
}
declare enum ScrollDirection {
    UP = "up",
    DOWN = "down",
    LEFT = "left",
    RIGHT = "right"
}
declare type ScrollDirectionState = Partial<Record<ScrollDirection, boolean>>;
declare type ScrollParams = ScrollSize & ScrollPosition & ClientSize;
declare type EventListenerFn = (type: 'scroll', callback: () => void) => void;
declare type SetRefFn = (ref: any) => void;
declare type ScrollingContainerRef = Required<ScrollSize> & Required<ScrollPosition> & Required<ClientSize> & {
    addEventListener: EventListenerFn;
    removeEventListener: EventListenerFn;
};
declare type InfiniteScrollState = DatasetLength & Required<ScrollSize> & Required<ClientSize> & {
    isLoading: boolean;
    thresholdReached: ScrollDirectionState;
    computedScrollThreshold: Required<ScrollAxis<number>>;
};
declare type UseInfiniteScrollProps = DatasetLength & {
    hasMore: ScrollDirectionState;
    next: (direction: ScrollDirection) => Promise<void>;
    onScroll?: (value: Required<ScrollParams>) => void;
    scrollThreshold?: number | string;
    initialScroll?: {
        top?: number;
        left?: number;
    };
    reverse?: {
        column?: boolean;
        row?: boolean;
    };
};
interface UseInfiniteScrollResult {
    setRef: SetRefFn;
}
declare type InfiniteScrollProps = UseInfiniteScrollProps;
declare type ScrollOffsetValues = Required<ScrollDirectionState>;

declare const useInfiniteScroll: (props: UseInfiniteScrollProps) => UseInfiniteScrollResult;

declare class InfiniteScroll {
    props: InfiniteScrollProps;
    state: InfiniteScrollState;
    onCleanup?: () => void;
    _scrollingContainerRef?: ScrollingContainerRef;
    constructor(props: InfiniteScrollProps);
    _validateScrollValue: (scrollPosition: number, scrollSize: number, fallbackValue?: number) => number;
    _scroll: (this: InfiniteScroll, { scrollTop, scrollLeft }: ScrollPosition) => void;
    _computeThreshold: (this: InfiniteScroll) => void;
    _getPossibleDirections: (this: InfiniteScroll) => Required<ScrollOffsetValues>;
    _loadByDirection: (this: InfiniteScroll, direction1: ScrollDirection.UP | ScrollDirection.LEFT, direction2: ScrollDirection.DOWN | ScrollDirection.RIGHT, offset: Required<ScrollOffsetValues>) => Promise<void>;
    _checkOffsetAndLoadMore: (this: InfiniteScroll) => void;
    _setRef: (this: InfiniteScroll, ref: any) => void;
    _onLoadComplete: (this: InfiniteScroll, axis: ScrollAxisName) => void;
    _onPropsChange: (this: InfiniteScroll, props: UseInfiniteScrollProps) => void;
    setRef: (ref: any) => void;
    onPropsChange: (props: UseInfiniteScrollProps) => void;
}

export { ClientSize, DatasetLength, EventListenerFn, InfiniteScroll, InfiniteScrollProps, InfiniteScrollState, ScrollAxis, ScrollAxisName, ScrollDirection, ScrollDirectionState, ScrollOffsetValues, ScrollParams, ScrollPosition, ScrollSize, ScrollingContainerRef, SetRefFn, UseInfiniteScrollProps, UseInfiniteScrollResult, useInfiniteScroll as default, useInfiniteScroll };
